@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Routines to sleep while reading commands while ips is in loop mode.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -218,6 +218,16 @@ ReadCommands(void)
 
 				break;
 
+			case 'M':
+				/*
+				 * Set the myprocs option.
+				 */
+				myProcs = (GetParsedNumber(!myProcs) != 0);
+				isWakeup = TRUE;
+				TopPage();
+
+				break;
+
 			case 'n':
 				/*
 				 * Move to next page of data.
@@ -260,6 +270,16 @@ ReadCommands(void)
 
 				break;
 
+			case 'S':
+				/*
+				 * Set the no self option.
+				 */
+				noSelf = (GetParsedNumber(!noSelf) != 0);
+				isWakeup = TRUE;
+				TopPage();
+
+				break;
+
 			case '\177':
 			case '\b':
 				/*
@@ -279,6 +299,16 @@ ReadCommands(void)
 
 				break;
 
+			case 'R':
+				/*
+				 * Set the no root option.
+				 */
+				noRoot = (GetParsedNumber(!noRoot) != 0);
+				isWakeup = TRUE;
+				TopPage();
+
+				break;
+
 			case '.':
 				/*
 				 * Parse part of a floating point argument.
