@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Conditional display routines.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -519,7 +519,11 @@ EvaluateFunction(TREE * tree, const NODE * node)
 
 	/*
 	 * Evaluate the number of arguments indicated by the function id.
+	 * Initialise the arguments to bad values in case of problems.
 	 */
+	arg1 = badValue;
+	arg2 = badValue;
+
 	switch (FUNCTION_ARGS(node->intVal))
 	{
 		case 2:	arg2 = EvaluateNode(tree, node->child[1]);
@@ -768,6 +772,8 @@ FunctionCmp(TREE * tree, VALUE arg1, VALUE arg2)
 	{
 		value.type = VALUE_NUMBER;
 		value.intVal = 0;
+		value.column = 0;
+		value.strVal = 0;
 
 		if (arg1.intVal < arg2.intVal)
 			value.intVal = -1;
@@ -806,6 +812,8 @@ FunctionCmp(TREE * tree, VALUE arg1, VALUE arg2)
 	 */
 	value.type = VALUE_NUMBER;
 	value.intVal = strcmp(arg1.strVal, arg2.strVal);
+	value.column = 0;
+	value.strVal = 0;
 
 	if (value.intVal < 0)
 		value.intVal = -1;
@@ -1505,7 +1513,7 @@ ParseShift(TREE * tree)
 			return top;
 	}
 
-	return NewNode(tree, OP_LEFTSHIFT, top, ParseUnary(tree));
+	return NewNode(tree, op, top, ParseUnary(tree));
 }
 
 
