@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Global definitions.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -264,11 +264,11 @@ struct	PROC
 	 * value.
 	 */
 	int	oldState;
-	int	oldFlags;
 	long	oldMinorFaults;
 	long	oldMajorFaults;
 	long	oldUserRunTime;
 	long	oldSystemRunTime;
+	ULONG	oldFlags;
 	ULONG	oldStartTimeTicks;
 	ULONG	oldEndCode;	
 	ULONG	oldEsp;
