@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Linux-specific process information collection routines.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -406,7 +406,11 @@ ExamineProcessId(pid_t pid, pthread_t tid)
 		}
 
 		if (noRoot && (statBuf.st_uid == 0))
+		{
+			(void) close(fd);
+
 			return;
+		}
 
 		if ((userCount > 0))
 		{
@@ -710,7 +714,7 @@ GetProcessWaitSymbol(PROC * proc)
 	 * Open the wait channel file and read it into a buffer
 	 * including trying to read one extra character.
 	 */
-	sprintf(name, "%s/%ld/waitChan", PROCDIR, (long) proc->pid);
+	sprintf(name, "%s/%ld/wchan", PROCDIR, (long) proc->pid);
 
 	fd = open(name, O_RDONLY);
 	len = -1;
