@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Command line option parsing.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -13,9 +13,9 @@
 /*
  * Definitions for version printout.
  */
-#define	VERSION		"4.0"
+#define	VERSION		"4.2"
 #define	AUTHOR_NAME	"David I. Bell"
-#define	AUTHOR_EMAIL	"dbell@canb.auug.org.au"
+#define	AUTHOR_EMAIL	"dbell@tip.net.au"
 
 
 /*
