@@ -2,7 +2,7 @@
  * Configurable ps-like program.
  * Useful utility routines.
  *
- * Copyright (c) 2010 David I. Bell
+ * Copyright (c) 2014 David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  */
@@ -139,10 +139,7 @@ struct	SHARED_STR
 static	SHARED_STR *	sharedTable[SHARED_HASH_SIZE];
 
 
-/*
- * The offset into the entry of the string buffer.
- */
-#define	SHARED_BUF_OFFSET	((int) (((SHARED_STR *) 0)->buf))
+static	SHARED_STR	dummySharedStr;
 
 
 /*
@@ -261,9 +258,13 @@ FreeSharedString(char * str)
 
 	/*
 	 * Back up to the entry header of the string and make sure that it
-	 * looks reasonable.
+	 * looks reasonable.  Calculate the offset to back up by using a
+	 * dummy instance of the structure.
 	 */
-	entry = (SHARED_STR *) (str - SHARED_BUF_OFFSET);
+	char * beg = (char *) &dummySharedStr;
+	char * end = (char *) &dummySharedStr.buf;
+
+	entry = (SHARED_STR *) (str - (end - beg));
 
 	tableIndex = entry->tableIndex;
 
